%bcond_with bootstrap

Name:           plexus-compiler
Version:        2.15.0
Release:        %mkrel 1
Group:          Development/Java
Summary:        Compiler call initiators for Plexus
# extras subpackage has a bit different licensing
# parts of compiler-api are Apache-2.0/MIT
License:        MIT AND Apache-2.0
URL:            https://github.com/codehaus-plexus/plexus-compiler
BuildArch:      noarch
#ExclusiveArch:  %%{java_arches} noarch

Source0:        https://github.com/codehaus-plexus/%{name}/archive/%{name}-%{version}.tar.gz
Source1:        https://www.apache.org/licenses/LICENSE-2.0.txt
Source2:        LICENSE.MIT

%if %{with bootstrap}
BuildRequires:  javapackages-bootstrap
%else
BuildRequires:  maven-local
BuildRequires:  mvn(javax.inject:javax.inject)
BuildRequires:  mvn(org.codehaus.plexus:plexus-utils)
BuildRequires:  mvn(org.codehaus.plexus:plexus:pom:)
BuildRequires:  mvn(org.eclipse.sisu:org.eclipse.sisu.plexus)
BuildRequires:  mvn(org.eclipse.sisu:sisu-maven-plugin)
BuildRequires:  mvn(org.slf4j:slf4j-api)
%endif

%description
Plexus Compiler adds support for using various compilers from a
unified api. Support for javac is available in main package. For
additional compilers see %{name}-extras package.

%package extras
Summary:        Extra compiler support for %{name}
# Apache-2.0: src/main/java/org/codehaus/plexus/compiler/util/scan/
#          ...codehaus/plexus/compiler/csharp/CSharpCompiler.java
# Apache-1.1/MIT: ...codehaus/plexus/compiler/jikes/JikesCompiler.java
License:        MIT AND Apache-2.0 AND Apache-1.1

%description extras
Additional support for csharp, eclipse and jikes compilers

%package pom
Summary:        Maven POM files for %{name}

%description pom
This package provides %{summary}.

%package javadoc
Summary:        Javadoc for %{name}
License:        MIT AND Apache-2.0 AND Apache-1.1

%description javadoc
API documentation for %{name}.

%prep
%setup -q -n %{name}-%{name}-%{version}

find -name '.class' -delete

cp %{SOURCE1} LICENSE
cp %{SOURCE2} LICENSE.MIT

%pom_remove_dep :junit-bom

%pom_disable_module plexus-compiler-aspectj plexus-compilers
# missing com.google.errorprone:error_prone_core
%pom_disable_module plexus-compiler-javac-errorprone plexus-compilers

%pom_disable_module plexus-compiler-eclipse plexus-compilers

# don't build/install compiler-test module, it needs maven2 test harness
%pom_disable_module plexus-compiler-test
%pom_disable_module plexus-compiler-its

# don't install sources jars
%mvn_package ":*::sources:" __noinstall

%mvn_package ":plexus-compiler{,s}" pom
%mvn_package ":*{csharp,eclipse,jikes}*" extras

# don't generate requires on test dependency (see #1007498)
%pom_xpath_remove "pom:dependency[pom:artifactId[text()='plexus-compiler-test']]" plexus-compilers

%pom_remove_plugin :maven-site-plugin
%pom_remove_plugin :maven-enforcer-plugin

%pom_remove_dep -r org.codehaus.plexus:plexus-compiler-javac-errorprone
%pom_remove_dep org.codehaus.plexus:plexus-xml plexus-compiler-manager

%build
# Tests are skipped because of unavailable plexus-compiler-test artifact
%mvn_build -f

%install
%mvn_install

%files -f .mfiles
%license LICENSE LICENSE.MIT
%files extras -f .mfiles-extras
%files pom -f .mfiles-pom

%files javadoc -f .mfiles-javadoc
%license LICENSE LICENSE.MIT


%changelog
* Thu Jun 20 2024 daviddavid <daviddavid> 2.15.0-1.mga10
+ Revision: 2075811
- Update to upstream version 2.15.0

* Wed May 22 2024 ns80 <ns80> 2.14.2-1.mga10
+ Revision: 2066043
- new version 2.14.2 for java 21

* Mon Jul 25 2022 neoclust <neoclust> 2.11.1-2.mga9
+ Revision: 1871106
- Disable bootstrap

* Sun Jul 24 2022 neoclust <neoclust> 2.11.1-1.mga9
+ Revision: 1870884
- New version 2.11.1
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Sat Sep 05 2020 daviddavid <daviddavid> 0:2.8.8-1.mga8
+ Revision: 1622562
- Update to version 2.8.8

* Wed Aug 19 2020 neoclust <neoclust> 0:2.8.6-1.mga8
+ Revision: 1615958
- New version 2.8.6

* Fri Feb 14 2020 umeabot <umeabot> 0:2.8.2-2.mga8
+ Revision: 1519324
- Mageia 8 Mass Rebuild

* Thu Oct 11 2018 guillomovitch <guillomovitch> 0:2.8.2-1.mga7
+ Revision: 1319565
- new version 2.8.2

* Wed Sep 19 2018 umeabot <umeabot> 0:2.7-5.mga7
+ Revision: 1274436
- Mageia 7 Mass Rebuild

* Sun May 07 2017 neoclust <neoclust> 0:2.7-4.mga6
+ Revision: 1099560
- Remove unneeded build-requires
- Second rebuild of the java stack

* Wed Feb 24 2016 neoclust <neoclust> 0:2.7-2.mga6
+ Revision: 977788
- First rebuild of the java stack
- sync package plexus-compiler with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Wed Dec 31 2014 pterjan <pterjan> 0:2.3-6.mga5
+ Revision: 807832
- Rebuild to get updated dependencies

* Wed Oct 15 2014 umeabot <umeabot> 0:2.3-5.mga5
+ Revision: 749749
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild
- Mageia 4 Mass Rebuild
+ dmorgan <dmorgan>
- Fix Requires

* Sun Sep 29 2013 dmorgan <dmorgan> 0:2.3-1.mga4
+ Revision: 489369
- New version
- Rebuild against new javapackages

* Tue Jul 09 2013 dmorgan <dmorgan> 0:2.2-3.mga4
+ Revision: 452167
- Remove auxiliary aliases

* Tue Jul 09 2013 dmorgan <dmorgan> 0:2.2-2.mga4
+ Revision: 452154
- Add auxiliary aliases

* Tue Jul 09 2013 dmorgan <dmorgan> 0:2.2-1.mga4
+ Revision: 452132
- New version 2.2

* Tue Jul 09 2013 dmorgan <dmorgan> 0:2.1-3.mga4
+ Revision: 452109
- Remove auxiliary aliases

* Tue Jul 09 2013 dmorgan <dmorgan> 0:2.1-2.mga4
+ Revision: 452097
- Build with original POM files
- with aliases to temporarily created artifact IDs
- Update to version 2.1 ( bootstrap )

* Tue Jul 09 2013 dmorgan <dmorgan> 0:1.9.2-6.mga4
+ Revision: 451576
- Build version 1.9.2 with xmvn
- New version

* Mon Jul 08 2013 dmorgan <dmorgan> 0:1.9.2-4.mga4
+ Revision: 451522
- Revert to version 1.9.2

* Mon Jul 08 2013 dmorgan <dmorgan> 0:2.1-1.mga4
+ Revision: 451390
- New version
  Build with xmvn

* Fri Jul 05 2013 dmorgan <dmorgan> 0:1.9.2-3.mga4
+ Revision: 450310
- Java Stack Rebuild to fix Requires

* Sun Jan 13 2013 umeabot <umeabot> 0:1.9.2-2.mga3
+ Revision: 377855
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 08 2013 dmorgan <dmorgan> 0:1.9.2-1.mga3
+ Revision: 343218
- New version
- Remove plexus-maven-plugin as builddep

* Thu Jul 05 2012 dmorgan <dmorgan> 0:1.9.1-1.mga3
+ Revision: 267947
- New version 1.9.1
- New version 1.8.3
- Build with maven 3
- Don't install compiler-test module (nothing should use it anyway)
- Fixes accoding to current guidelines
- Install depmaps into extras separately

* Thu Apr 28 2011 dmorgan <dmorgan> 0:1.8-3.mga1
+ Revision: 93017
- Rebuild after bootstrapping
- imported package plexus-compiler


* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0:1.8-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Jan 20 2011 Stanislav Ochotnicky <sochotnicky@redhat.com> - 0:1.8-1
- Update to latest version (1.8)
- Create extras subpackage with optional compilers
- Provide maven depmaps
- Versionless jars & javadocs

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0:1.5.2-4.3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0:1.5.2-3.3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Jul  9 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0:1.5.2-2.3
- drop repotag

* Thu Mar 15 2007 Deepak Bhole <dbhole@redhat.com> - 0:1.5.2-2jpp.2
- Fix bug in spec that prevented unversioned symlink creation

* Thu Mar 08 2007 Deepak Bhole <dbhole@redhat.com> - 0:1.5.2-2jpp.1
- Fix license
- Disable aspectj compiler until we can put that into Fedora
- Remove vendor and distribution tags
- Removed javadoc post and postuns, with dirs being marked %%doc now
- Fix buildroot per Fedora spec

* Fri Jun 02 2006 Ralph Apel <r.apel at r-apel.de> - 0:1.5.2-2jpp
- Fix jar naming to previous plexus conventions

* Tue May 30 2006 Ralph Apel <r.apel at r-apel.de> - 0:1.5.2-1jpp
- First JPackage build

